InitResult class

A class that represents the result of app initialization.

Constructors

InitResult({required bool complete, dynamic error, dynamic stackTrace, bool showsError = true, String? errorMessage})
Constructs an instance of InitResult.
const

Properties

complete → bool
Whether the app initialization is complete.
final
error → dynamic
An error occurred during the app initialization.
final
errorMessage → String?
The error message to display when showsError is true.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showsError → bool
Whether to show a dialog when an error occurs.
final
stackTrace → dynamic
The stackTrace of the error.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited